#!/bin/bash

LIBEXEC="/usr/libexec"

USAGE="usage: $0 command provider"
HELP="$0 is the script to start different provider for catapult"

if [[ $# -ne 2 ]]; then
	echo "There must be exactly two arguments."
	echo $USAGE
	exit 1
fi

PROV="$LIBEXEC/catapult/$2"
OBJPATH="/org/gentoo/catapult"
INTERFACE="org.gentoo.catapult.Admin"
DEST="org.gentoo.catapult.$2"
NAME="Catapult '$2'"

start ()
{
	if [[ ! -x $PROV ]]; then
		echo "ERROR: Starter file for provider $1 is not existing or not executable."
		exit 1
	fi

	exec $PROV
}

status ()
{
	if dbus-send --dest="org.freedesktop.DBus" --print-reply "/" "org.freedesktop.DBus.NameHasOwner" "string:${DEST}" | grep "true" > /dev/null; then
		echo "${NAME} is currently running."
		return 0
	else
		echo "${NAME} is currently not running."
		return 1
	fi
}

_do ()
{
	if dbus-send --dest="${DEST}" --print-reply "${OBJPATH}" "${INTERFACE}.$1"; then
		echo "${NAME}: \"${1}\" successfull"
		return 0
	else
		echo "${NAME}: \"${1}\" failed"
		return 1
	fi
}

case $1 in
	start) start $2 ;;
	status) status $2 ;;
	stop) _do stop $2 ;;
	ping) _do ping $2 ;;
	*) echo "Wrong command. Chose from 'start', 'ping', 'status', and 'stop'."
	exit 1;;
esac
